Properties Methods Events Config Options Direct Link

    Filter
      DateFilter

# Class Ext.ux.grid.filter.DateFilter

Package: | Ext.ux.grid.filter
Defined In: | DateFilter.js
Class: | DateFilter
Extends: | Filter

Filter by a configurable Ext.menu.DateMenu

Example Usage:

    var filters = new Ext.ux.grid.GridFilters({
        ...
        filters: [{
            // required configs
            type: 'date',
            dataIndex: 'dateAdded',

            // optional configs
            dateFormat: 'm/d/Y',  // default
            beforeText: 'Before', // default
            afterText: 'After',   // default
            onText: 'On',         // default
            pickerOpts: {
                // any DateMenu configs
            },

            active: true // default is false
        }]
    });

## Config Options

Config Options | Defined By
--- | ---
| active : Boolean Indicates the initial status of the filter (defaults to false). | Filter
| afterText : String Defaults to 'After'. | DateFilter
| afterText : String Defaults to 'After'. | DateFilter
| beforeText : String Defaults to 'Before'. | DateFilter
| beforeText : String Defaults to 'Before'. | DateFilter
| compareMap : Object Map for assigning the comparison values used in serialization. | DateFilter
| compareMap : Object Map for assigning the comparison values used in serialization. | DateFilter
| dataIndex : String The Ext.data.Store dataIndex of the field this filter represents. The dataIndex does not actually have to exist in th... The Ext.data.Store dataIndex of the field this filter represents. The dataIndex does not actually have to exist in the store. | Filter
| dateFormat : String The date format to return when using getValue. Defaults to 'm/d/Y'. | DateFilter
| dateFormat : String The date format to return when using getValue. Defaults to 'm/d/Y'. | DateFilter
| maxDate : Date Allowable date as passed to the Ext.DatePicker Defaults to undefined. | DateFilter
| maxDate : Date Allowable date as passed to the Ext.DatePicker Defaults to undefined. | DateFilter
| menuItemCfgs : Object Default configuration options for each menu item | DateFilter
| menuItemCfgs : Object Default configuration options for each menu item | DateFilter
| menuItems : Array The items to be shown in this menu Defaults to:
    menuItems : ['before', 'after', '-', 'on'],
| DateFilter
| menuItems : Array The items to be shown in this menu Defaults to:
    menuItems : ['before', 'after', '-', 'on'],
| DateFilter
| minDate : Date Allowable date as passed to the Ext.DatePicker Defaults to undefined. | DateFilter
| minDate : Date Allowable date as passed to the Ext.DatePicker Defaults to undefined. | DateFilter
| onText : String Defaults to 'On'. | DateFilter
| onText : String Defaults to 'On'. | DateFilter
| pickerOpts : Object Configuration options for the date picker associated with each field. | DateFilter
| pickerOpts : Object Configuration options for the date picker associated with each field. | DateFilter
| updateBuffer : Number Number of milliseconds to wait after user interaction to fire an update. Only supported by filters: 'list', 'numeric... Number of milliseconds to wait after user interaction to fire an update. Only supported by filters: 'list', 'numeric', and 'string'. Defaults to 500. | Filter

## Public Properties

Property | Defined By
--- | ---
| active : Boolean True if this filter is active. Use setActive() to alter after configuration. | Filter
| getSerialArgs : Object Template method to be implemented by all subclasses that is to get and return serialized filter data for transmission... Template method to be implemented by all subclasses that is to get and return serialized filter data for transmission to the server. Defaults to Ext.emptyFn. | Filter
| init : Object Template method to be implemented by all subclasses that is to initialize the filter and install required menu items.... Template method to be implemented by all subclasses that is to initialize the filter and install required menu items. Defaults to Ext.emptyFn. | Filter
| menu : Ext.menu.Menu The filter configuration menu that will be installed into the filter submenu of a column menu. | Filter

## Public Methods

Method | Defined By
--- | ---
| destroy() : void Destroys this filter by purging any event listeners, and removing any menus. Destroys this filter by purging any event listeners, and removing any menus. Parameters: None. Returns: void | Filter
| getFieldValue( `String item` ) : Date Get and return the date menu picker value Get and return the date menu picker value Parameters: `item` : String The field identifier ('before', 'after', 'on') Returns: `Date` Gets the current selected value of the date field | DateFilter
| getPicker( `String item` ) : Object Gets the menu picker associated with the passed field Gets the menu picker associated with the passed field Parameters: `item` : String The field identifier ('before', 'after', 'on') Returns: `Object` The menu picker | DateFilter
| getValue() : Object Template method to be implemented by all subclasses that is to get and return the value of the filter. Defaults to Ex... Template method to be implemented by all subclasses that is to get and return the value of the filter. Defaults to Ext.emptyFn. Parameters: None. Returns: `Object` The 'serialized' form of this filter | Filter
| isActivatable() : Boolean Template method to be implemented by all subclasses that is to return true if the filter has enough configuration inf... Template method to be implemented by all subclasses that is to return `true` if the filter has enough configuration information to be activated. Defaults to `return true`. Parameters: None. Returns: `Boolean` | Filter
| onMenuSelect( `Object date`, `Object menuItem`, `Object value`, `Object picker` ) : void Handler for when the menu for a field fires the 'select' event Handler for when the menu for a field fires the 'select' event Parameters: `date` : Object `menuItem` : Object `value` : Object `picker` : Object Returns: void | DateFilter
| serialize() : Object/Array Returns the serialized filter data for transmission to the server and fires the 'serialize' event. Returns the serialized filter data for transmission to the server and fires the 'serialize' event. Parameters: None. Returns: `Object/Array` An object or collection of objects containing key value pairs representing the current configuration of the filter. | Filter
| setActive( `Boolean active`, `Boolean suppressEvent` ) : void Sets the status of the filter and fires the appropriate events. Sets the status of the filter and fires the appropriate events. Parameters: `active` : Boolean The new filter state. `suppressEvent` : Boolean True to prevent events from being fired. Returns: void | Filter
| setValue( `Object data` ) : void Template method to be implemented by all subclasses that is to set the value of the filter and fire the 'update' even... Template method to be implemented by all subclasses that is to set the value of the filter and fire the 'update' event. Defaults to Ext.emptyFn. Parameters: `data` : Object The value to set the filter Returns: void | Filter
| validateRecord( `Ext.data.Record record` ) : Boolean Template method that is to validate the provided Ext.data.Record against the filters configuration. Template method that is to validate the provided Ext.data.Record against the filters configuration. Parameters: `record` : Ext.data.Record The record to validate Returns: `Boolean` true if the record is valid within the bounds of the filter, false otherwise. | DateFilter

## Public Events

Event | Defined By
--- | ---
| activate : ( `Ext.ux.grid.filter.Filter this` ) Fires when an inactive filter becomes active Fires when an inactive filter becomes active Listeners will be called with the following arguments: `this` : Ext.ux.grid.filter.Filter | Filter
| deactivate : ( `Ext.ux.grid.filter.Filter this` ) Fires when an active filter becomes inactive Fires when an active filter becomes inactive Listeners will be called with the following arguments: `this` : Ext.ux.grid.filter.Filter | Filter
| serialize : ( `Array/Object data`, `Ext.ux.grid.filter.Filter filter` ) Fires after the serialization process. Use this to attach additional parameters to serialization data before it is en... Fires after the serialization process. Use this to attach additional parameters to serialization data before it is encoded and sent to the server. Listeners will be called with the following arguments: `data` : Array/Object A map or collection of maps representing the current filter configuration. `filter` : Ext.ux.grid.filter.Filter The filter being serialized. | Filter
| update : ( `Ext.ux.grid.filter.Filter this` ) Fires when a filter configuration has changed Fires when a filter configuration has changed Listeners will be called with the following arguments: `this` : Ext.ux.grid.filter.Filter The filter object. | Filter